@@ -1,15 +1,12 @@
 # -*- perl -*-
 ##----------------------------------------------------------------------------
 ## Database Object Interface - ~/lib/DB/Object/Postgres.pm
-## Version 0.4.5
-## Copyright(c) 2019 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <jack@deguest.jp>
+## Version v0.4.6
+## Copyright(c) 2020 DEGUEST Pte. Ltd.
+## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2017/07/19
-## Modified 2020/01/19
-## All rights reserved
+## Modified 2020/05/21
 ## 
-## This program is free software; you can redistribute  it  and/or  modify  it
-## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 ## This is the subclassable module for driver specific ones.
 package DB::Object::Postgres;
@@ -27,7 +24,7 @@ BEGIN
         DBD::Pg->import( ':pg_types' );
     };
     die( $@ ) if( $@ );
-    use TryCatch;
+    use Nice::Try;
     use DateTime;
     use DateTime::Format::Strptime;
     require DB::Object::Postgres::Statement;
@@ -35,7 +32,7 @@ BEGIN
     require DB::Object::Postgres::Lo;
     our( $VERSION, $DB_ERRSTR, $ERROR, $DEBUG, $CONNECT_VIA, $CACHE_QUERIES, $CACHE_SIZE );
     our( $CACHE_TABLE, $USE_BIND, $USE_CACHE, $MOD_PERL, @DBH );
-    $VERSION     = '0.4.5';
+    $VERSION     = 'v0.4.6';
     use Devel::Confess;
 };
 
